==> haskell-crypto-pubkey-types-0.4.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-6oEMBzxBsId4AzA8T5Nhde
key: crypto-pubkey-types-0.4.3-6oEMBzxBsId4AzA8T5Nhde
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Types.PubKey.RSA Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.ECC
    Crypto.Types.PubKey.ECDSA
abi: 2d9b42c1f63ed0e47349cc8716d22e5a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-types-0.4.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-6oEMBzxBsId4AzA8T5Nhde
depends:
    asn1-encoding-0.9.4-Az92imiHLOLFcqxR2hoR73
    asn1-types-0.3.2-666D9GcolNS7cz58NvfKzt base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-CWExMNWH08f6oxoT1I7j0w
key: crypto-pubkey-types-0.4.3-CWExMNWH08f6oxoT1I7j0w
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Types.PubKey.RSA Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.ECC
    Crypto.Types.PubKey.ECDSA
abi: 44f4fa969a9bfd51a719674e57d03667
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-types-0.4.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-CWExMNWH08f6oxoT1I7j0w
depends:
    asn1-encoding-0.9.5-9w4TFvLCDTrJjV3qDKgpV9
    asn1-types-0.3.2-666D9GcolNS7cz58NvfKzt base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
